.. _policies:

Policies
--------

We try not to have too many rules and regulations (everything abovehas been nothing more than advice we offer to make things easier for you, given that we learned much of it the hard way). Generally, chapter organizers are free to do whatever they want, as long as it’s in the best interest of their local chapter and/or PyLadies in general.

The following policies have been written up so that you may simply copy and paste them into email responses, to help you deal with awkward or tricky situations.

Code of Conduct
~~~~~~~~~~~~~~~

Pyladies is dedicated to providing a respectful, harassment-free community for everyone. We do not tolerate harassment or bullying of any community member in any form. This does not only extend to members to local PyLadies communities, but to anyone who chooses to become involved in the larger PyLadies community of users, developers and integrators through events or interactions.

Harassment includes offensive verbal/electronic comments related to personal characteristics or choices, sexual images or comments in public or online spaces, deliberate intimidation, bullying, stalking, following, harassing photography or recording, sustained disruption of talks, IRC chats, electronic meetings, physical meetings or other events, inappropriate physical contact, or unwelcome sexual attention. Participants asked to stop any harassing or bullying behavior are expected to comply immediately.

If a participant engages in harassing behavior, representatives of the community may take reasonable action they deem appropriate, including warning the offender, expulsion from any PyLadies event, or expulsion from mailing lists, IRC chats, discussion boards and other electronic communications channels to resolve the issue. This may include expulsion from PyLadies Meetup group membership.

If you are being harassed, notice that someone else is being harassed, or have any other concerns, please act to intercede or ask for help from any member of the PyLadies community, IRC chat admins, website admins, or organizers/representatives of any physical events put on under the auspices of PyLadies.

This Code of Conduct has been adapted from the `Plone Foundation`_ and is licensed under a Creative Commons Attribution-Share Alike 3.0 Unported `license`_.

.. _Plone Foundation: http://plone.org/foundation/materials/foundation-resolutions/code-of-conduct
.. _license: http://creativecommons.org/licenses/by-sa/3.0/

Official PyLadies Guest Policy
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

(If anyone asks to stay with you in the future other than a trusted friend, say something like "I wish we could accommodate you, but
PyLadies has a strict policy of not allowing members to host out-of-town guests" and then paste this, minus the parenthetical note.)

In the interest of safety and security of our members, PyLadies organizers, volunteers, and members are not permitted to host overnight out-of-town guests who wish to visit town for PyLadies events.

This is a strict formal policy, chosen to ensure that the PyLadies organization continues to be taken seriously and treated with complete respect by the professional software and tech communities.

Policy on Controversial Issues
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

As a PyLadies local chapter organizer, you may be asked for PyLadies’ position on controversial issues. Often, these are diversity-related issues.

PyLadies’ policy is to have no official position on controversial issues. By choosing this policy, we allow ourselves to be a group full of diverse ideas and differing viewpoints.